# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agatha_protobuf/analysis/analysis.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'agatha_protobuf/analysis/analysis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'agatha_protobuf/analysis/analysis.proto\x12\x08\x61nalysis\x1a\x1bgoogle/protobuf/empty.proto\"@\n\x0e\x41nalyzeRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontext\x18\x03 \x01(\t\"3\n\x0f\x41nalyzeResponse\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"2\n\x13\x41nalyzeLLMSResponse\x12\x1b\n\x04llms\x18\x01 \x03(\x0b\x32\r.analysis.LLM\"@\n\x03LLM\x12\x0c\n\x04name\x18\x01 \x01(\t\x12+\n\x08response\x18\x02 \x01(\x0b\x32\x19.analysis.AnalyzeResponse\"\x80\x01\n\x15\x43reateFeedbackRequest\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\r\n\x05scale\x18\x02 \x01(\t\x12\x0f\n\x07\x61nalyze\x18\x03 \x01(\t\x12\x12\n\x05\x62uild\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05model\x18\x05 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_buildB\x08\n\x06_model\"7\n\x13HealthCheckResponse\x12\x0f\n\x07healthy\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t2\xb9\x02\n\x0f\x41nalysisService\x12\x44\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a\x1d.analysis.HealthCheckResponse\x12\x42\n\x0b\x41nalyzeText\x12\x18.analysis.AnalyzeRequest\x1a\x19.analysis.AnalyzeResponse\x12N\n\x13\x41nalyzeTextFromLLMS\x12\x18.analysis.AnalyzeRequest\x1a\x1d.analysis.AnalyzeLLMSResponse\x12L\n\x0e\x43reateFeedback\x12\x1f.analysis.CreateFeedbackRequest\x1a\x19.analysis.AnalyzeResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agatha_protobuf.analysis.analysis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ANALYZEREQUEST']._serialized_start=82
  _globals['_ANALYZEREQUEST']._serialized_end=146
  _globals['_ANALYZERESPONSE']._serialized_start=148
  _globals['_ANALYZERESPONSE']._serialized_end=199
  _globals['_ANALYZELLMSRESPONSE']._serialized_start=201
  _globals['_ANALYZELLMSRESPONSE']._serialized_end=251
  _globals['_LLM']._serialized_start=253
  _globals['_LLM']._serialized_end=317
  _globals['_CREATEFEEDBACKREQUEST']._serialized_start=320
  _globals['_CREATEFEEDBACKREQUEST']._serialized_end=448
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=450
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=505
  _globals['_ANALYSISSERVICE']._serialized_start=508
  _globals['_ANALYSISSERVICE']._serialized_end=821
# @@protoc_insertion_point(module_scope)
